@@ -5,7 +5,17 @@ import sys
 import tempfile
 from configparser import ConfigParser
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Tuple, Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    List,
+    Optional,
+    Tuple,
+    Union,
+    no_type_check,
+)
 
 import py
 import pytest
@@ -174,16 +184,6 @@ class YamlTestItem(pytest.Item):
             ):
                 parent_dir.rmdir()
 
-    def find_dependent_paths(self, path: Path) -> List[Path]:
-        py_module = ".".join(path.with_suffix("").parts)
-        dependants = []
-        for dirpath, _, filenames in os.walk(self.incremental_cache_dir):
-            for filename in filenames:
-                path = Path(dirpath) / filename
-                if f'"{py_module}"' in path.read_text():
-                    dependants.append(path.with_suffix("").with_suffix(""))
-        return dependants
-
     def typecheck_in_new_subprocess(
         self, execution_path: Path, mypy_cmd_options: List[Any]
     ) -> Tuple[int, Tuple[str, str]]:
@@ -240,8 +240,14 @@ class YamlTestItem(pytest.Item):
         try:
             temp_dir = tempfile.TemporaryDirectory(prefix="pytest-mypy-", dir=self.root_directory)
 
+        except (FileNotFoundError, PermissionError, NotADirectoryError) as e:
+
+            raise TypecheckAssertionError(
+                error_message=f"Testing base directory {self.root_directory} must exist and be writable"
+            ) from e
+
+        try:
             execution_path = Path(temp_dir.name)
-            assert execution_path.exists()
 
             with utils.cd(execution_path):
                 # extension point for derived packages
@@ -284,16 +290,12 @@ class YamlTestItem(pytest.Item):
 
         finally:
             temp_dir.cleanup()
-            # remove created modules and all their dependants from cache
+            # remove created modules
             if not self.disable_cache:
                 for file in self.files:
                     path = Path(file.path)
                     self.remove_cache_files(path.with_suffix(""))
 
-                    dependants = self.find_dependent_paths(path)
-                    for dependant in dependants:
-                        self.remove_cache_files(dependant)
-
         assert not os.path.exists(temp_dir.name)
 
     def prepare_mypy_cmd_options(self, execution_path: Path) -> List[str]:
@@ -308,9 +310,6 @@ class YamlTestItem(pytest.Item):
         if not self.disable_cache:
             mypy_cmd_options.extend(["--cache-dir", self.incremental_cache_dir])
 
-        python_version = ".".join([str(part) for part in sys.version_info[:2]])
-        mypy_cmd_options.append(f"--python-version={python_version}")
-
         # Merge `self.base_ini_fpath` and `self.additional_mypy_config`
         # into one file and copy to the typechecking folder:
         mypy_ini_config = ConfigParser()
@@ -354,8 +353,11 @@ class YamlTestItem(pytest.Item):
         else:
             return super().repr_failure(excinfo, style="native")
 
-    def reportinfo(self) -> Tuple[Union[py.path.local, str], Optional[int], str]:
-        return self.fspath, None, self.name
+    @no_type_check
+    def reportinfo(self) -> Tuple[Union[py.path.local, Path, str], Optional[int], str]:
+        # To support both Pytest 6.x and 7.x
+        path = getattr(self, "path", None) or getattr(self, "fspath")
+        return path, None, self.name
 
     def _collect_python_path(
         self,
